Reset log file
Details
Logs are saved by project name and date (date created, not date modified).
For example, "pollock_2021-05-12.json". Calls to log functions are
automatically appended to the existing project log file. Resetting the log
file will create a new project log file with the current date. A log will
not be reset if log_reset() is run the same day the log was created
(or if the log is reset two or more times in a single day), unless
over_write = TRUE. This will replace that day's log file.