Used for creating new columns.
Details
name_check() first checks to see if new column names are unique
and returns an error if not. When repair = TRUE, name_check()
will check for unique column names and returns new column names that are
unique and syntactic (see vec_as_names for details).