Re-cast intersecting multi-polygons to polygons. Used when combining regulatory zones with closure areas.
Details
This function is primarily used to extract polygons during
the ID re-labeling process performed by new_zone_id. If
a polygon from grid intersected with closure, it is extracted
from it's multi-polygon and given a unique ID.