Define zone closure scenarios
Arguments
- project
Required, name of project.
- spatname
Required, data file or character.
spatis a spatial data file containing information on fishery management or regulatory zone boundaries. Shape, json, geojson, and csv formats are supported. geojson is the preferred format. json files must be converted into geojson. This is done automatically when the file is loaded withread_datwithis.mapset to true.spatcannot, at this time, be loaded from the FishSET database.- zone_spat
Variable in
spatthat identifies the individual areas or zones.- lon_spat
Required for csv files. Variable or list from
spatcontaining longitude data. Leave as NULL ifspatis a shape or json file.- lat_spat
Required for csv files. Variable or list from
spatcontaining latitude data. Leave as NULL ifspatis a shape or json file.- epsg
EPSG number. Set the epsg to ensure that
spathas the correct projections. If epsg is not specified but is defined forspat. See http://spatialreference.org/ to help identify the optimal epsg number.
Details
Define zone closure scenarios via an interactive app. Users can define scenarios by clicking on one or more zones on the map, adjusting the allowable TAC percentages in the table, and entering a unique scenario name. Clicking 'Add closure' instantly saves the scenario to the project database. These saved choices are later called in the policy scenario function.